@@ -7,7 +7,7 @@ import subprocess
 from PySide6.QtCore import QCoreApplication
 
 from pupgui2.constants import IS_FLATPAK
-from pupgui2.util import fetch_project_release_data, fetch_project_releases
+from pupgui2.util import fetch_project_release_data
 
 from pupgui2.resources.ctmods.ctmod_00protonge import CtInstaller as GEProtonInstaller
 
@@ -29,7 +29,7 @@ class CtInstaller(GEProtonInstaller):
 
         self.release_format = 'tar.xz'
     
-    def __fetch_github_data(self, tag):
+    def __fetch_github_data(self, tag: str) -> dict:
 
         """
         Fetch GitHub release information
@@ -56,11 +56,15 @@ class CtInstaller(GEProtonInstaller):
         ldd_min = int(ldd_ver.split(b'.')[1])
         return False if ldd_maj < 2 else ldd_min >= 27 or ldd_maj != 2
 
-    def fetch_releases(self, count: int = 100, page: int = 1) -> list[str]:
- 
+    def get_extract_dir(self, install_dir: str) -> str:
+
         """
-        List available releases
-        Return Type: str[]
+        Return the directory to extract Lutris-Wine archive based on the current launcher
+        Return Type: str
         """
 
-        return fetch_project_releases(self.CT_URL, self.rs, count=count, page=page)
+        # GE-Proton ctmod figures out if it needs to into a different folder
+        #
+        # kron4ek can use default 'install_dir' always because it is Wine and not Proton,
+        # so override to return unmodified 'install_dir'
+        return install_dir
