@@ -128,7 +128,7 @@ def apply_dark_theme(app: QApplication) -> None:
                 app.setPalette(QStyleFactory.create('fusion').standardPalette())
 
 
-def read_update_config_value(option: str, value = None, section: str = 'pupgui2', config_file: str = CONFIG_FILE) -> str | None:
+def read_update_config_value(option: str, value: str | None = None, section: str = 'pupgui2', config_file: str = CONFIG_FILE) -> str | None:
     """
     Uses ConfigParser to read a value with a given option from a given section from a given config file.
     By default, will read a option and a value from the 'pupgui2' section in CONFIG_FILE path in constants.py.
@@ -165,7 +165,7 @@ def read_update_config_value(option: str, value = None, section: str = 'pupgui2'
     return value
 
 
-def config_theme(theme=None) -> str | None:
+def config_theme(theme: str | None = None) -> str | None:
     """
     Read/update config for the theme
     Write theme to config or read if theme=None
@@ -421,7 +421,7 @@ def open_webbrowser_thread(url: str) -> None:
     Open the specified URL in the default webbrowser. Non-blocking (using Threads)
     """
     try:
-        t = threading.Thread(target=webbrowser.open, args=[url])
+        t = threading.Thread(target = webbrowser.open, args = [url], name = '_webbrowser_open')
         t.start()
     except:
         print(f'Could not open webbrowser url {url}')
@@ -498,7 +498,7 @@ def download_awacy_gamelist() -> None:
     if not is_online():
         return
 
-    t = threading.Thread(target=_download_awacy_gamelist_thread)
+    t = threading.Thread(target = _download_awacy_gamelist_thread, name = '_download_awacy_gamelist')
     t.start()
 
 
@@ -529,7 +529,7 @@ def get_installed_ctools(install_dir: str) -> list[BasicCompatTool]:
     return ctools
 
 
-def host_which(name: str) -> str:
+def host_which(name: str) -> str | None:
     """
     Runs 'which <name>' on the host system (either normal or using 'flatpak-spawn --host' when inside Flatpak)
     Return Type: str
@@ -608,7 +608,6 @@ def is_online(host: str = 'https://api.github.com/rate_limit/', timeout: int = 5
         return False
 
 
-# Only used for dxvk and dxvk-async right now, but is potentially useful to more ctmods?
 def fetch_project_releases(releases_url: str, rs: requests.Session, count: int = 100, page: int = 1, include_extra_asset: Callable[..., list[str]] | None = None) -> list[str]:
 
     """
